@@ -98,7 +98,7 @@ def neq_(one, two, msg = None):
 def eq_pprint(a, b, msg=None):
     if a != b:
         log.error(msg)
-        assert False
+        return False
     return True
 
 def _eq_list(ca, cb, ignore=None):
@@ -120,7 +120,6 @@ def _eq_dict(ca, cb, ignore=None):
                 del ca[key]
             if key in cb:
                 del cb[key]
-    return True
 
     #this needs to be recursive so we can '&ignore'-out ids anywhere in a json stream
     for key in set(ca.keys() + cb.keys()):
